@@ -8,7 +8,7 @@ describe Ethon::Easy::Http do
     let(:action_name) { :get }
     let(:options) { {} }
 
-    let(:get) { mock(:setup) }
+    let(:get) { double(:setup) }
     let(:get_class) { Ethon::Easy::Http::Get }
 
     it "instanciates action" do
@@ -31,6 +31,25 @@ describe Ethon::Easy::Http do
             easy.perform
             expect(easy.response_body).to include("\"REQUEST_METHOD\":\"#{action.to_s.upcase}\"")
           end
+
+          it "streams the response body from the #{action.to_s.upcase} request" do
+            bytes_read = 0
+            easy.on_body { |chunk, response| bytes_read += chunk.bytesize }
+            easy.http_request(url, action, options)
+            easy.perform
+            content_length = ((easy.response_headers =~ /Content-Length: (\d+)/) && $1.to_i)
+            expect(bytes_read).to eq(content_length)
+            expect(easy.response_body).to eq("")
+          end
+
+          it "notifies when headers are ready" do
+            headers = []
+            easy.on_headers { |r| headers << r.response_headers }
+            easy.http_request(url, action, options)
+            easy.perform
+            expect(headers).to eq([easy.response_headers])
+            expect(headers.first).to match(/Content-Length: (\d+)/)
+          end
         end
       end
 
